# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from conekta.models.checkout_order_template import CheckoutOrderTemplate

class Checkout(BaseModel):
    """
    It is a sub-resource of the Order model that can be stipulated in order to configure its corresponding checkout
    """
    allowed_payment_methods: conlist(StrictStr) = Field(..., description="Those are the payment methods that will be available for the link")
    expires_at: StrictInt = Field(..., description="It is the time when the link will expire. It is expressed in seconds since the Unix epoch. The valid range is from 2 to 365 days (the valid range will be taken from the next day of the creation date at 00:01 hrs) ")
    monthly_installments_enabled: Optional[StrictBool] = Field(None, description="This flag allows you to specify if months without interest will be active.")
    monthly_installments_options: Optional[conlist(StrictInt)] = Field(None, description="This field allows you to specify the number of months without interest.")
    name: StrictStr = Field(..., description="Reason for charge")
    needs_shipping_contact: Optional[StrictBool] = Field(None, description="This flag allows you to fill in the shipping information at checkout.")
    on_demand_enabled: Optional[StrictBool] = Field(None, description="This flag allows you to specify if the link will be on demand.")
    order_template: CheckoutOrderTemplate = Field(...)
    payments_limit_count: Optional[StrictInt] = Field(None, description="It is the number of payments that can be made through the link.")
    recurrent: StrictBool = Field(..., description="false: single use. true: multiple payments")
    type: StrictStr = Field(..., description="It is the type of link that will be created. It must be a valid type.")
    __properties = ["allowed_payment_methods", "expires_at", "monthly_installments_enabled", "monthly_installments_options", "name", "needs_shipping_contact", "on_demand_enabled", "order_template", "payments_limit_count", "recurrent", "type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Checkout:
        """Create an instance of Checkout from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of order_template
        if self.order_template:
            _dict['order_template'] = self.order_template.to_dict()
        # set to None if on_demand_enabled (nullable) is None
        # and __fields_set__ contains the field
        if self.on_demand_enabled is None and "on_demand_enabled" in self.__fields_set__:
            _dict['on_demand_enabled'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Checkout:
        """Create an instance of Checkout from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Checkout.parse_obj(obj)

        _obj = Checkout.parse_obj({
            "allowed_payment_methods": obj.get("allowed_payment_methods"),
            "expires_at": obj.get("expires_at"),
            "monthly_installments_enabled": obj.get("monthly_installments_enabled"),
            "monthly_installments_options": obj.get("monthly_installments_options"),
            "name": obj.get("name"),
            "needs_shipping_contact": obj.get("needs_shipping_contact"),
            "on_demand_enabled": obj.get("on_demand_enabled"),
            "order_template": CheckoutOrderTemplate.from_dict(obj.get("order_template")) if obj.get("order_template") is not None else None,
            "payments_limit_count": obj.get("payments_limit_count"),
            "recurrent": obj.get("recurrent"),
            "type": obj.get("type")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.webhook_keys_api import WebhookKeysApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestWebhookKeysApi(unittest.TestCase):
    """WebhookKeysApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.webhook_keys_api.WebhookKeysApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_create_webhook_key(self):
        """Test case for create_webhook_key

        Create Webhook Key  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.WebhookKeyRequest(
            active=True
        )
        response = self.api.create_webhook_key(accept_language, rq)
        self.assertIsNotNone(response)

    def test_delete_webhook_key(self):
        """Test case for delete_webhook_key

        Delete Webhook key  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.delete_webhook_key('645a59da22e7da0001cad283', accept_language)
        self.assertIsNotNone(response)

    def test_get_webhook_key(self):
        """Test case for get_webhook_key

        Get Webhook Key  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_webhook_key('645a5eb022e7da0001cad2a4', accept_language)
        self.assertIsNotNone(response)

    def test_get_webhook_keys(self):
        """Test case for get_webhook_keys

        Get List of Webhook Keys  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_webhook_keys(accept_language, limit=2)
        self.assertIsNotNone(response)

    def test_update_webhook_key(self):
        """Test case for update_webhook_key

        Update Webhook Key  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.WebhookKeyUpdateRequest(
            active=False
        )
        response = self.api.update_webhook_key('645a613622e7da0001cad882', accept_language, rq)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, constr

class TokenCard(BaseModel):
    """
    TokenCard
    """
    cvc: constr(strict=True, max_length=4) = Field(..., description="It is a value that allows identifying the security code of the card.")
    device_fingerprint: Optional[StrictStr] = Field(None, description="It is a value that allows identifying the device fingerprint.")
    exp_month: constr(strict=True, max_length=2) = Field(..., description="It is a value that allows identifying the expiration month of the card.")
    exp_year: constr(strict=True, max_length=2) = Field(..., description="It is a value that allows identifying the expiration year of the card.")
    name: StrictStr = Field(..., description="It is a value that allows identifying the name of the cardholder.")
    number: StrictStr = Field(..., description="It is a value that allows identifying the number of the card.")
    __properties = ["cvc", "device_fingerprint", "exp_month", "exp_year", "name", "number"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TokenCard:
        """Create an instance of TokenCard from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TokenCard:
        """Create an instance of TokenCard from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TokenCard.parse_obj(obj)

        _obj = TokenCard.parse_obj({
            "cvc": obj.get("cvc"),
            "device_fingerprint": obj.get("device_fingerprint"),
            "exp_month": obj.get("exp_month"),
            "exp_year": obj.get("exp_year"),
            "name": obj.get("name"),
            "number": obj.get("number")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.tokens_api import TokensApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestTokensApi(unittest.TestCase):
    """TokensApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.tokens_api.TokensApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_create_token(self):
        """Test case for create_token

        Create Token  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.Token(
            card=conekta.TokenCard(
                cvc='123',
                exp_month='07',
                exp_year='27',
                name='Foo Foo',
                number='5475040095304607'
            )
        )
        response = self.api.create_token(rq, accept_language)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr
from conekta.models.customer_shipping_contacts_response_address import CustomerShippingContactsResponseAddress

class OrderResponseShippingContact(BaseModel):
    """
    OrderResponseShippingContact
    """
    created_at: Optional[StrictInt] = None
    id: Optional[StrictStr] = None
    object: Optional[StrictStr] = None
    phone: Optional[StrictStr] = None
    receiver: Optional[StrictStr] = None
    between_streets: Optional[StrictStr] = None
    address: Optional[CustomerShippingContactsResponseAddress] = None
    parent_id: Optional[StrictStr] = None
    default: Optional[StrictBool] = None
    deleted: Optional[StrictBool] = None
    __properties = ["created_at", "id", "object", "phone", "receiver", "between_streets", "address", "parent_id", "default", "deleted"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OrderResponseShippingContact:
        """Create an instance of OrderResponseShippingContact from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict['address'] = self.address.to_dict()
        # set to None if between_streets (nullable) is None
        # and __fields_set__ contains the field
        if self.between_streets is None and "between_streets" in self.__fields_set__:
            _dict['between_streets'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OrderResponseShippingContact:
        """Create an instance of OrderResponseShippingContact from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return OrderResponseShippingContact.parse_obj(obj)

        _obj = OrderResponseShippingContact.parse_obj({
            "created_at": obj.get("created_at"),
            "id": obj.get("id"),
            "object": obj.get("object"),
            "phone": obj.get("phone"),
            "receiver": obj.get("receiver"),
            "between_streets": obj.get("between_streets"),
            "address": CustomerShippingContactsResponseAddress.from_dict(obj.get("address")) if obj.get("address") is not None else None,
            "parent_id": obj.get("parent_id"),
            "default": obj.get("default"),
            "deleted": obj.get("deleted")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from conekta.models.token_card import TokenCard
from conekta.models.token_checkout import TokenCheckout

class Token(BaseModel):
    """
    a token
    """
    card: Optional[TokenCard] = None
    checkout: Optional[TokenCheckout] = None
    __properties = ["card", "checkout"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Token:
        """Create an instance of Token from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of card
        if self.card:
            _dict['card'] = self.card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of checkout
        if self.checkout:
            _dict['checkout'] = self.checkout.to_dict()
        # set to None if card (nullable) is None
        # and __fields_set__ contains the field
        if self.card is None and "card" in self.__fields_set__:
            _dict['card'] = None

        # set to None if checkout (nullable) is None
        # and __fields_set__ contains the field
        if self.checkout is None and "checkout" in self.__fields_set__:
            _dict['checkout'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Token:
        """Create an instance of Token from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Token.parse_obj(obj)

        _obj = Token.parse_obj({
            "card": TokenCard.from_dict(obj.get("card")) if obj.get("card") is not None else None,
            "checkout": TokenCheckout.from_dict(obj.get("checkout")) if obj.get("checkout") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist, constr

class PaymentMethodCard(BaseModel):
    """
    PaymentMethodCard
    """
    type: Optional[StrictStr] = None
    object: StrictStr = Field(...)
    account_type: Optional[StrictStr] = None
    auth_code: Optional[StrictStr] = None
    brand: Optional[StrictStr] = None
    contract_id: Optional[constr(strict=True, max_length=10, min_length=10)] = Field(None, description="Id sent for recurrent charges.")
    country: Optional[StrictStr] = None
    exp_month: Optional[StrictStr] = None
    exp_year: Optional[StrictStr] = None
    fraud_indicators: Optional[conlist(Any)] = None
    issuer: Optional[StrictStr] = None
    last4: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    __properties = ["type", "object", "account_type", "auth_code", "brand", "contract_id", "country", "exp_month", "exp_year", "fraud_indicators", "issuer", "last4", "name"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PaymentMethodCard:
        """Create an instance of PaymentMethodCard from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PaymentMethodCard:
        """Create an instance of PaymentMethodCard from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PaymentMethodCard.parse_obj(obj)

        _obj = PaymentMethodCard.parse_obj({
            "type": obj.get("type"),
            "object": obj.get("object"),
            "account_type": obj.get("account_type"),
            "auth_code": obj.get("auth_code"),
            "brand": obj.get("brand"),
            "contract_id": obj.get("contract_id"),
            "country": obj.get("country"),
            "exp_month": obj.get("exp_month"),
            "exp_year": obj.get("exp_year"),
            "fraud_indicators": obj.get("fraud_indicators"),
            "issuer": obj.get("issuer"),
            "last4": obj.get("last4"),
            "name": obj.get("name")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import json
import pprint
import re  # noqa: F401

from typing import Any, List, Optional
from pydantic import BaseModel, Field, StrictStr, ValidationError, validator
from conekta.models.payment_method_bank_transfer import PaymentMethodBankTransfer
from conekta.models.payment_method_card import PaymentMethodCard
from conekta.models.payment_method_cash import PaymentMethodCash
from typing import Any, List
from pydantic import StrictStr, Field

CHARGERESPONSEPAYMENTMETHOD_ONE_OF_SCHEMAS = ["PaymentMethodBankTransfer", "PaymentMethodCard", "PaymentMethodCash"]

class ChargeResponsePaymentMethod(BaseModel):
    """
    ChargeResponsePaymentMethod
    """
    # data type: PaymentMethodCash
    oneof_schema_1_validator: Optional[PaymentMethodCash] = None
    # data type: PaymentMethodCard
    oneof_schema_2_validator: Optional[PaymentMethodCard] = None
    # data type: PaymentMethodBankTransfer
    oneof_schema_3_validator: Optional[PaymentMethodBankTransfer] = None
    actual_instance: Any
    one_of_schemas: List[str] = Field(CHARGERESPONSEPAYMENTMETHOD_ONE_OF_SCHEMAS, const=True)

    class Config:
        validate_assignment = True

    discriminator_value_class_map = {
    }

    def __init__(self, *args, **kwargs):
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = ChargeResponsePaymentMethod.construct()
        error_messages = []
        match = 0
        # validate data type: PaymentMethodCash
        if not isinstance(v, PaymentMethodCash):
            error_messages.append(f"Error! Input type `{type(v)}` is not `PaymentMethodCash`")
        else:
            match += 1
        # validate data type: PaymentMethodCard
        if not isinstance(v, PaymentMethodCard):
            error_messages.append(f"Error! Input type `{type(v)}` is not `PaymentMethodCard`")
        else:
            match += 1
        # validate data type: PaymentMethodBankTransfer
        if not isinstance(v, PaymentMethodBankTransfer):
            error_messages.append(f"Error! Input type `{type(v)}` is not `PaymentMethodBankTransfer`")
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when setting `actual_instance` in ChargeResponsePaymentMethod with oneOf schemas: PaymentMethodBankTransfer, PaymentMethodCard, PaymentMethodCash. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when setting `actual_instance` in ChargeResponsePaymentMethod with oneOf schemas: PaymentMethodBankTransfer, PaymentMethodCard, PaymentMethodCash. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: dict) -> ChargeResponsePaymentMethod:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> ChargeResponsePaymentMethod:
        """Returns the object represented by the json string"""
        instance = ChargeResponsePaymentMethod.construct()
        error_messages = []
        match = 0

        # use oneOf discriminator to lookup the data type
        _data_type = json.loads(json_str).get("object")
        if not _data_type:
            raise ValueError("Failed to lookup data type from the field `object` in the input.")

        # check if data type is `PaymentMethodBankTransfer`
        if _data_type == "bank_transfer_payment":
            instance.actual_instance = PaymentMethodBankTransfer.from_json(json_str)
            return instance

        # check if data type is `PaymentMethodCard`
        if _data_type == "card_payment":
            instance.actual_instance = PaymentMethodCard.from_json(json_str)
            return instance

        # check if data type is `PaymentMethodCash`
        if _data_type == "cash_payment":
            instance.actual_instance = PaymentMethodCash.from_json(json_str)
            return instance

        # check if data type is `PaymentMethodBankTransfer`
        if _data_type == "payment_method_bank_transfer":
            instance.actual_instance = PaymentMethodBankTransfer.from_json(json_str)
            return instance

        # check if data type is `PaymentMethodCard`
        if _data_type == "payment_method_card":
            instance.actual_instance = PaymentMethodCard.from_json(json_str)
            return instance

        # check if data type is `PaymentMethodCash`
        if _data_type == "payment_method_cash":
            instance.actual_instance = PaymentMethodCash.from_json(json_str)
            return instance

        # deserialize data into PaymentMethodCash
        try:
            instance.actual_instance = PaymentMethodCash.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into PaymentMethodCard
        try:
            instance.actual_instance = PaymentMethodCard.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into PaymentMethodBankTransfer
        try:
            instance.actual_instance = PaymentMethodBankTransfer.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into ChargeResponsePaymentMethod with oneOf schemas: PaymentMethodBankTransfer, PaymentMethodCard, PaymentMethodCash. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into ChargeResponsePaymentMethod with oneOf schemas: PaymentMethodBankTransfer, PaymentMethodCard, PaymentMethodCash. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        to_json = getattr(self.actual_instance, "to_json", None)
        if callable(to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> dict:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        to_dict = getattr(self.actual_instance, "to_dict", None)
        if callable(to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.dict())




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import conekta
from conekta.api.balances_api import BalancesApi  # noqa: E501
from conekta.rest import ApiException


class TestBalancesApi(unittest.TestCase):
    """BalancesApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.balances_api.BalancesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_balance(self):
        """Test case for get_balance

        Get a company's balance  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import Field, StrictStr, conint

from typing import Optional

from conekta.models.get_orders_response import GetOrdersResponse
from conekta.models.order_capture_request import OrderCaptureRequest
from conekta.models.order_refund_request import OrderRefundRequest
from conekta.models.order_request import OrderRequest
from conekta.models.order_response import OrderResponse
from conekta.models.order_update_request import OrderUpdateRequest

from conekta.api_client import ApiClient
from conekta.api_response import ApiResponse
from conekta.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class OrdersApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def cancel_order(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> OrderResponse:  # noqa: E501
        """Cancel Order  # noqa: E501

        Cancel an order that has been previously created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.cancel_order(id, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: OrderResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the cancel_order_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.cancel_order_with_http_info(id, accept_language, x_child_company_id, **kwargs)  # noqa: E501

    @validate_arguments
    def cancel_order_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Cancel Order  # noqa: E501

        Cancel an order that has been previously created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.cancel_order_with_http_info(id, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(OrderResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'accept_language',
            'x_child_company_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_order" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['accept_language']:
            _header_params['Accept-Language'] = _params['accept_language']

        if _params['x_child_company_id']:
            _header_params['X-Child-Company-Id'] = _params['x_child_company_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.conekta-v2.1.0+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "OrderResponse",
            '401': "Error",
            '402': "Error",
            '404': "Error",
            '428': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/orders/{id}/cancel', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def create_order(self, order_request : Annotated[OrderRequest, Field(..., description="requested field for order")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> OrderResponse:  # noqa: E501
        """Create order  # noqa: E501

        Create a new order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_order(order_request, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param order_request: requested field for order (required)
        :type order_request: OrderRequest
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: OrderResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the create_order_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.create_order_with_http_info(order_request, accept_language, x_child_company_id, **kwargs)  # noqa: E501

    @validate_arguments
    def create_order_with_http_info(self, order_request : Annotated[OrderRequest, Field(..., description="requested field for order")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Create order  # noqa: E501

        Create a new order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_order_with_http_info(order_request, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param order_request: requested field for order (required)
        :type order_request: OrderRequest
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(OrderResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'order_request',
            'accept_language',
            'x_child_company_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_order" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['accept_language']:
            _header_params['Accept-Language'] = _params['accept_language']

        if _params['x_child_company_id']:
            _header_params['X-Child-Company-Id'] = _params['x_child_company_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['order_request'] is not None:
            _body_params = _params['order_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.conekta-v2.1.0+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "OrderResponse",
            '422': "Error",
            '401': "Error",
            '402': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/orders', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_order_by_id(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> OrderResponse:  # noqa: E501
        """Get Order  # noqa: E501

        Info for a specific order  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_order_by_id(id, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: OrderResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_order_by_id_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_order_by_id_with_http_info(id, accept_language, x_child_company_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_order_by_id_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Get Order  # noqa: E501

        Info for a specific order  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_order_by_id_with_http_info(id, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(OrderResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'accept_language',
            'x_child_company_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_order_by_id" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['accept_language']:
            _header_params['Accept-Language'] = _params['accept_language']

        if _params['x_child_company_id']:
            _header_params['X-Child-Company-Id'] = _params['x_child_company_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.conekta-v2.1.0+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "OrderResponse",
            '401': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/orders/{id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_orders(self, accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, limit : Annotated[Optional[conint(strict=True, le=250, ge=1)], Field(description="The numbers of items to return, the maximum value is 250")] = None, search : Annotated[Optional[StrictStr], Field(description="General order search, e.g. by mail, reference etc.")] = None, next : Annotated[Optional[StrictStr], Field(description="next page")] = None, previous : Annotated[Optional[StrictStr], Field(description="previous page")] = None, **kwargs) -> GetOrdersResponse:  # noqa: E501
        """Get a list of Orders  # noqa: E501

        Get order details in the form of a list  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_orders(accept_language, x_child_company_id, limit, search, next, previous, async_req=True)
        >>> result = thread.get()

        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param limit: The numbers of items to return, the maximum value is 250
        :type limit: int
        :param search: General order search, e.g. by mail, reference etc.
        :type search: str
        :param next: next page
        :type next: str
        :param previous: previous page
        :type previous: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetOrdersResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_orders_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_orders_with_http_info(accept_language, x_child_company_id, limit, search, next, previous, **kwargs)  # noqa: E501

    @validate_arguments
    def get_orders_with_http_info(self, accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, limit : Annotated[Optional[conint(strict=True, le=250, ge=1)], Field(description="The numbers of items to return, the maximum value is 250")] = None, search : Annotated[Optional[StrictStr], Field(description="General order search, e.g. by mail, reference etc.")] = None, next : Annotated[Optional[StrictStr], Field(description="next page")] = None, previous : Annotated[Optional[StrictStr], Field(description="previous page")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Get a list of Orders  # noqa: E501

        Get order details in the form of a list  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_orders_with_http_info(accept_language, x_child_company_id, limit, search, next, previous, async_req=True)
        >>> result = thread.get()

        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param limit: The numbers of items to return, the maximum value is 250
        :type limit: int
        :param search: General order search, e.g. by mail, reference etc.
        :type search: str
        :param next: next page
        :type next: str
        :param previous: previous page
        :type previous: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GetOrdersResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'accept_language',
            'x_child_company_id',
            'limit',
            'search',
            'next',
            'previous'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orders" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('search') is not None:  # noqa: E501
            _query_params.append(('search', _params['search']))

        if _params.get('next') is not None:  # noqa: E501
            _query_params.append(('next', _params['next']))

        if _params.get('previous') is not None:  # noqa: E501
            _query_params.append(('previous', _params['previous']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['accept_language']:
            _header_params['Accept-Language'] = _params['accept_language']

        if _params['x_child_company_id']:
            _header_params['X-Child-Company-Id'] = _params['x_child_company_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.conekta-v2.1.0+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "GetOrdersResponse",
            '401': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/orders', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def order_cancel_refund(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], refund_id : Annotated[StrictStr, Field(..., description="refund identifier")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> OrderResponse:  # noqa: E501
        """Cancel Refund  # noqa: E501

        A refunded order describes the items, amount, and reason an order is being refunded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.order_cancel_refund(id, refund_id, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param refund_id: refund identifier (required)
        :type refund_id: str
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: OrderResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the order_cancel_refund_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.order_cancel_refund_with_http_info(id, refund_id, accept_language, x_child_company_id, **kwargs)  # noqa: E501

    @validate_arguments
    def order_cancel_refund_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], refund_id : Annotated[StrictStr, Field(..., description="refund identifier")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Cancel Refund  # noqa: E501

        A refunded order describes the items, amount, and reason an order is being refunded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.order_cancel_refund_with_http_info(id, refund_id, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param refund_id: refund identifier (required)
        :type refund_id: str
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(OrderResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'refund_id',
            'accept_language',
            'x_child_company_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method order_cancel_refund" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']

        if _params['refund_id']:
            _path_params['refund_id'] = _params['refund_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['accept_language']:
            _header_params['Accept-Language'] = _params['accept_language']

        if _params['x_child_company_id']:
            _header_params['X-Child-Company-Id'] = _params['x_child_company_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.conekta-v2.1.0+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "OrderResponse",
            '401': "Error",
            '402': "Error",
            '404': "Error",
            '422': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/orders/{id}/refunds/{refund_id}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def order_refund(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], order_refund_request : Annotated[OrderRefundRequest, Field(..., description="requested field for a refund")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> OrderResponse:  # noqa: E501
        """Refund Order  # noqa: E501

        A refunded order describes the items, amount, and reason an order is being refunded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.order_refund(id, order_refund_request, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param order_refund_request: requested field for a refund (required)
        :type order_refund_request: OrderRefundRequest
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: OrderResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the order_refund_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.order_refund_with_http_info(id, order_refund_request, accept_language, x_child_company_id, **kwargs)  # noqa: E501

    @validate_arguments
    def order_refund_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], order_refund_request : Annotated[OrderRefundRequest, Field(..., description="requested field for a refund")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Refund Order  # noqa: E501

        A refunded order describes the items, amount, and reason an order is being refunded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.order_refund_with_http_info(id, order_refund_request, accept_language, x_child_company_id, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param order_refund_request: requested field for a refund (required)
        :type order_refund_request: OrderRefundRequest
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(OrderResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'order_refund_request',
            'accept_language',
            'x_child_company_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method order_refund" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['accept_language']:
            _header_params['Accept-Language'] = _params['accept_language']

        if _params['x_child_company_id']:
            _header_params['X-Child-Company-Id'] = _params['x_child_company_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['order_refund_request'] is not None:
            _body_params = _params['order_refund_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.conekta-v2.1.0+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "OrderResponse",
            '401': "Error",
            '402': "Error",
            '404': "Error",
            '422': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/orders/{id}/refunds', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def orders_create_capture(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, order_capture_request : Annotated[Optional[OrderCaptureRequest], Field(description="requested fields for capture order")] = None, **kwargs) -> OrderResponse:  # noqa: E501
        """Capture Order  # noqa: E501

        Processes an order that has been previously authorized.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.orders_create_capture(id, accept_language, x_child_company_id, order_capture_request, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param order_capture_request: requested fields for capture order
        :type order_capture_request: OrderCaptureRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: OrderResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the orders_create_capture_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.orders_create_capture_with_http_info(id, accept_language, x_child_company_id, order_capture_request, **kwargs)  # noqa: E501

    @validate_arguments
    def orders_create_capture_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, x_child_company_id : Annotated[Optional[StrictStr], Field(description="In the case of a holding company, the company id of the child company to which will process the request.")] = None, order_capture_request : Annotated[Optional[OrderCaptureRequest], Field(description="requested fields for capture order")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Capture Order  # noqa: E501

        Processes an order that has been previously authorized.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.orders_create_capture_with_http_info(id, accept_language, x_child_company_id, order_capture_request, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param x_child_company_id: In the case of a holding company, the company id of the child company to which will process the request.
        :type x_child_company_id: str
        :param order_capture_request: requested fields for capture order
        :type order_capture_request: OrderCaptureRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(OrderResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'accept_language',
            'x_child_company_id',
            'order_capture_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method orders_create_capture" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['accept_language']:
            _header_params['Accept-Language'] = _params['accept_language']

        if _params['x_child_company_id']:
            _header_params['X-Child-Company-Id'] = _params['x_child_company_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['order_capture_request'] is not None:
            _body_params = _params['order_capture_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.conekta-v2.1.0+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "OrderResponse",
            '401': "Error",
            '404': "Error",
            '428': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/orders/{id}/capture', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def update_order(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], order_update_request : Annotated[OrderUpdateRequest, Field(..., description="requested field for an order")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, **kwargs) -> OrderResponse:  # noqa: E501
        """Update Order  # noqa: E501

        Update an existing Order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_order(id, order_update_request, accept_language, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param order_update_request: requested field for an order (required)
        :type order_update_request: OrderUpdateRequest
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: OrderResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the update_order_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.update_order_with_http_info(id, order_update_request, accept_language, **kwargs)  # noqa: E501

    @validate_arguments
    def update_order_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Identifier of the resource")], order_update_request : Annotated[OrderUpdateRequest, Field(..., description="requested field for an order")], accept_language : Annotated[Optional[StrictStr], Field(description="Use for knowing which language to use")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Update Order  # noqa: E501

        Update an existing Order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_order_with_http_info(id, order_update_request, accept_language, async_req=True)
        >>> result = thread.get()

        :param id: Identifier of the resource (required)
        :type id: str
        :param order_update_request: requested field for an order (required)
        :type order_update_request: OrderUpdateRequest
        :param accept_language: Use for knowing which language to use
        :type accept_language: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(OrderResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'order_update_request',
            'accept_language'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_order" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['accept_language']:
            _header_params['Accept-Language'] = _params['accept_language']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['order_update_request'] is not None:
            _body_params = _params['order_update_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.conekta-v2.1.0+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "OrderResponse",
            '401': "Error",
            '404': "Error",
            '422': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/orders/{id}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conint, constr, validator

class PlanRequest(BaseModel):
    """
    a plan
    """
    amount: conint(strict=True, ge=1) = Field(..., description="The amount in cents that will be charged on the interval specified.")
    currency: Optional[constr(strict=True, max_length=3)] = Field(None, description="ISO 4217 for currencies, for the Mexican peso it is MXN/USD")
    expiry_count: Optional[StrictInt] = Field(None, description="Number of repetitions of the frequency NUMBER OF CHARGES TO BE MADE, considering the interval and frequency, this evolves over time, but is subject to the expiration count.")
    frequency: conint(strict=True, ge=1) = Field(..., description="Frequency of the charge, which together with the interval, can be every 3 weeks, every 4 months, every 2 years, every 5 fortnights")
    id: Optional[StrictStr] = Field(None, description="internal reference id")
    interval: StrictStr = Field(..., description="The interval of time between each charge.")
    name: StrictStr = Field(..., description="The name of the plan.")
    trial_period_days: Optional[StrictInt] = Field(None, description="The number of days the customer will have a free trial.")
    __properties = ["amount", "currency", "expiry_count", "frequency", "id", "interval", "name", "trial_period_days"]

    @validator('interval')
    def interval_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('week', 'half_month', 'month', 'year'):
            raise ValueError("must be one of enum values ('week', 'half_month', 'month', 'year')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PlanRequest:
        """Create an instance of PlanRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PlanRequest:
        """Create an instance of PlanRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PlanRequest.parse_obj(obj)

        _obj = PlanRequest.parse_obj({
            "amount": obj.get("amount"),
            "currency": obj.get("currency"),
            "expiry_count": obj.get("expiry_count"),
            "frequency": obj.get("frequency"),
            "id": obj.get("id"),
            "interval": obj.get("interval"),
            "name": obj.get("name"),
            "trial_period_days": obj.get("trial_period_days")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictStr, conint

class ShippingRequest(BaseModel):
    """
    ShippingRequest
    """
    amount: conint(strict=True, ge=0) = Field(..., description="Shipping amount in cents")
    carrier: Optional[StrictStr] = Field(None, description="Carrier name for the shipment")
    tracking_number: Optional[StrictStr] = Field(None, description="Tracking number can be used to track the shipment")
    method: Optional[StrictStr] = Field(None, description="Method of shipment")
    metadata: Optional[Dict[str, Any]] = Field(None, description="Hash where the user can send additional information for each 'shipping'.")
    __properties = ["amount", "carrier", "tracking_number", "method", "metadata"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ShippingRequest:
        """Create an instance of ShippingRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ShippingRequest:
        """Create an instance of ShippingRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ShippingRequest.parse_obj(obj)

        _obj = ShippingRequest.parse_obj({
            "amount": obj.get("amount"),
            "carrier": obj.get("carrier"),
            "tracking_number": obj.get("tracking_number"),
            "method": obj.get("method"),
            "metadata": obj.get("metadata")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, conlist, constr
from conekta.models.checkout_order_template_customer_info import CheckoutOrderTemplateCustomerInfo
from conekta.models.product import Product

class CheckoutOrderTemplate(BaseModel):
    """
    It maintains the attributes with which the order will be created when receiving a new payment.
    """
    currency: constr(strict=True, max_length=3) = Field(..., description="It is the currency in which the order will be created. It must be a valid ISO 4217 currency code.")
    customer_info: Optional[CheckoutOrderTemplateCustomerInfo] = None
    line_items: conlist(Product) = Field(..., description="They are the products to buy. Each contains the \"unit price\" and \"quantity\" parameters that are used to calculate the total amount of the order.")
    metadata: Optional[Dict[str, Any]] = Field(None, description="It is a set of key-value pairs that you can attach to the order. It can be used to store additional information about the order in a structured format.")
    __properties = ["currency", "customer_info", "line_items", "metadata"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CheckoutOrderTemplate:
        """Create an instance of CheckoutOrderTemplate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of customer_info
        if self.customer_info:
            _dict['customer_info'] = self.customer_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in line_items (list)
        _items = []
        if self.line_items:
            for _item in self.line_items:
                if _item:
                    _items.append(_item.to_dict())
            _dict['line_items'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CheckoutOrderTemplate:
        """Create an instance of CheckoutOrderTemplate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CheckoutOrderTemplate.parse_obj(obj)

        _obj = CheckoutOrderTemplate.parse_obj({
            "currency": obj.get("currency"),
            "customer_info": CheckoutOrderTemplateCustomerInfo.from_dict(obj.get("customer_info")) if obj.get("customer_info") is not None else None,
            "line_items": [Product.from_dict(_item) for _item in obj.get("line_items")] if obj.get("line_items") is not None else None,
            "metadata": obj.get("metadata")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr, constr

class PlanResponse(BaseModel):
    """
    plans model
    """
    amount: Optional[StrictInt] = None
    created_at: Optional[StrictInt] = None
    currency: Optional[constr(strict=True, max_length=3)] = None
    expiry_count: Optional[StrictInt] = None
    frequency: Optional[StrictInt] = None
    id: Optional[StrictStr] = None
    interval: Optional[StrictStr] = None
    livemode: Optional[StrictBool] = None
    name: Optional[StrictStr] = None
    object: Optional[StrictStr] = None
    trial_period_days: Optional[StrictInt] = None
    __properties = ["amount", "created_at", "currency", "expiry_count", "frequency", "id", "interval", "livemode", "name", "object", "trial_period_days"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PlanResponse:
        """Create an instance of PlanResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if expiry_count (nullable) is None
        # and __fields_set__ contains the field
        if self.expiry_count is None and "expiry_count" in self.__fields_set__:
            _dict['expiry_count'] = None

        # set to None if trial_period_days (nullable) is None
        # and __fields_set__ contains the field
        if self.trial_period_days is None and "trial_period_days" in self.__fields_set__:
            _dict['trial_period_days'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PlanResponse:
        """Create an instance of PlanResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PlanResponse.parse_obj(obj)

        _obj = PlanResponse.parse_obj({
            "amount": obj.get("amount"),
            "created_at": obj.get("created_at"),
            "currency": obj.get("currency"),
            "expiry_count": obj.get("expiry_count"),
            "frequency": obj.get("frequency"),
            "id": obj.get("id"),
            "interval": obj.get("interval"),
            "livemode": obj.get("livemode"),
            "name": obj.get("name"),
            "object": obj.get("object"),
            "trial_period_days": obj.get("trial_period_days")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.shippings_api import ShippingsApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestShippingsApi(unittest.TestCase):
    """ShippingsApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.shippings_api.ShippingsApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_orders_create_shipping(self):
        """Test case for orders_create_shipping

        Create Shipping  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.ShippingRequest(
            amount=100
        )
        response = self.api.orders_create_shipping('ord_2tUigJ8DgBhbp6w5D', rq, accept_language)
        self.assertIsNotNone(response)

    def test_orders_delete_shipping(self):
        """Test case for orders_delete_shipping

        Delete Shipping  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.orders_delete_shipping('ord_2tUigJ8DgBhbp6w5D', 'ship_lin_2tVzNuDGSaDwreMg6',
                                                   accept_language)
        self.assertIsNotNone(response)

    def test_orders_update_shipping(self):
        """Test case for orders_update_shipping

        Update Shipping  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.ShippingRequest(
            amount=100
        )
        response = self.api.orders_update_shipping('ord_2tUigJ8DgBhbp6w5D', 'ship_lin_2tVzNuDGSaDwreMg6', rq,
                                                   accept_language)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.products_api import ProductsApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestProductsApi(unittest.TestCase):
    """ProductsApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.products_api.ProductsApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_orders_create_product(self):
        """Test case for orders_create_product

        Create Product  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.Product(
            name='plan test',
            quantity=1,
            unit_price=1000
        )
        response = self.api.orders_create_product('ord_2tUigJ8DgBhbp6w5D', rq, accept_language)
        self.assertIsNotNone(response)

    def test_orders_delete_product(self):
        """Test case for orders_delete_product

        Delete Product  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.orders_delete_product('ord_2tUigJ8DgBhbp6w5D', 'line_item_2tVz8UkyWhSxLfUd7',
                                                  accept_language)
        self.assertIsNotNone(response)

    def test_orders_update_product(self):
        """Test case for orders_update_product

        Update Product  # noqa: E501
        """
        accept_language = 'es'
        rq = conekta.UpdateProduct(
            name='plan test',
            quantity=1,
            unit_price=1000
        )
        response = self.api.orders_update_product('ord_2tUigJ8DgBhbp6w5D', 'line_item_2tVz8UkyWhSxLfUd7', rq,
                                                  accept_language)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist

class CheckoutRequest(BaseModel):
    """
    [Checkout](https://developers.conekta.com/v2.1.0/reference/payment-link) details 
    """
    allowed_payment_methods: conlist(StrictStr) = Field(..., description="Are the payment methods available for this link")
    expires_at: Optional[StrictInt] = Field(None, description="Unix timestamp of checkout expiration")
    failure_url: Optional[StrictStr] = Field(None, description="Redirection url back to the site in case of failed payment, applies only to HostedPayment.")
    monthly_installments_enabled: Optional[StrictBool] = None
    monthly_installments_options: Optional[conlist(StrictInt)] = None
    name: Optional[StrictStr] = Field(None, description="Reason for payment")
    on_demand_enabled: Optional[StrictBool] = None
    success_url: Optional[StrictStr] = Field(None, description="Redirection url back to the site in case of successful payment, applies only to HostedPayment")
    type: Optional[StrictStr] = Field(None, description="This field represents the type of checkout")
    __properties = ["allowed_payment_methods", "expires_at", "failure_url", "monthly_installments_enabled", "monthly_installments_options", "name", "on_demand_enabled", "success_url", "type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CheckoutRequest:
        """Create an instance of CheckoutRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CheckoutRequest:
        """Create an instance of CheckoutRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CheckoutRequest.parse_obj(obj)

        _obj = CheckoutRequest.parse_obj({
            "allowed_payment_methods": obj.get("allowed_payment_methods"),
            "expires_at": obj.get("expires_at"),
            "failure_url": obj.get("failure_url"),
            "monthly_installments_enabled": obj.get("monthly_installments_enabled"),
            "monthly_installments_options": obj.get("monthly_installments_options"),
            "name": obj.get("name"),
            "on_demand_enabled": obj.get("on_demand_enabled"),
            "success_url": obj.get("success_url"),
            "type": obj.get("type")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist

class CheckoutResponse(BaseModel):
    """
    checkout response
    """
    allowed_payment_methods: Optional[conlist(StrictStr)] = None
    can_not_expire: Optional[StrictBool] = None
    emails_sent: Optional[StrictInt] = None
    exclude_card_networks: Optional[conlist(Dict[str, Any])] = None
    expires_at: Optional[StrictInt] = None
    failure_url: Optional[StrictStr] = None
    force_3ds_flow: Optional[StrictBool] = None
    id: StrictStr = Field(...)
    livemode: StrictBool = Field(...)
    metadata: Optional[Dict[str, Any]] = None
    monthly_installments_enabled: Optional[StrictBool] = None
    monthly_installments_options: Optional[conlist(StrictInt)] = None
    name: StrictStr = Field(..., description="Reason for charge")
    needs_shipping_contact: Optional[StrictBool] = None
    object: StrictStr = Field(...)
    paid_payments_count: Optional[StrictInt] = None
    payments_limit_count: Optional[StrictInt] = None
    recurrent: Optional[StrictBool] = None
    slug: Optional[StrictStr] = None
    sms_sent: Optional[StrictInt] = None
    starts_at: Optional[StrictInt] = None
    status: Optional[StrictStr] = None
    success_url: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    url: Optional[StrictStr] = None
    __properties = ["allowed_payment_methods", "can_not_expire", "emails_sent", "exclude_card_networks", "expires_at", "failure_url", "force_3ds_flow", "id", "livemode", "metadata", "monthly_installments_enabled", "monthly_installments_options", "name", "needs_shipping_contact", "object", "paid_payments_count", "payments_limit_count", "recurrent", "slug", "sms_sent", "starts_at", "status", "success_url", "type", "url"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CheckoutResponse:
        """Create an instance of CheckoutResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if payments_limit_count (nullable) is None
        # and __fields_set__ contains the field
        if self.payments_limit_count is None and "payments_limit_count" in self.__fields_set__:
            _dict['payments_limit_count'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CheckoutResponse:
        """Create an instance of CheckoutResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CheckoutResponse.parse_obj(obj)

        _obj = CheckoutResponse.parse_obj({
            "allowed_payment_methods": obj.get("allowed_payment_methods"),
            "can_not_expire": obj.get("can_not_expire"),
            "emails_sent": obj.get("emails_sent"),
            "exclude_card_networks": obj.get("exclude_card_networks"),
            "expires_at": obj.get("expires_at"),
            "failure_url": obj.get("failure_url"),
            "force_3ds_flow": obj.get("force_3ds_flow"),
            "id": obj.get("id"),
            "livemode": obj.get("livemode"),
            "metadata": obj.get("metadata"),
            "monthly_installments_enabled": obj.get("monthly_installments_enabled"),
            "monthly_installments_options": obj.get("monthly_installments_options"),
            "name": obj.get("name"),
            "needs_shipping_contact": obj.get("needs_shipping_contact"),
            "object": obj.get("object"),
            "paid_payments_count": obj.get("paid_payments_count"),
            "payments_limit_count": obj.get("payments_limit_count"),
            "recurrent": obj.get("recurrent"),
            "slug": obj.get("slug"),
            "sms_sent": obj.get("sms_sent"),
            "starts_at": obj.get("starts_at"),
            "status": obj.get("status"),
            "success_url": obj.get("success_url"),
            "type": obj.get("type"),
            "url": obj.get("url")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr, conlist

class LogsResponseData(BaseModel):
    """
    LogsResponseData
    """
    created_at: Optional[StrictInt] = None
    id: Optional[StrictStr] = None
    ip_address: Optional[StrictStr] = None
    livemode: Optional[StrictBool] = None
    loggable_id: Optional[StrictStr] = None
    loggable_type: Optional[StrictStr] = None
    method: Optional[StrictStr] = None
    oauth_token_id: Optional[StrictStr] = None
    query_string: Optional[Dict[str, Any]] = None
    related: Optional[StrictStr] = None
    request_body: Optional[Dict[str, Any]] = None
    request_headers: Optional[Dict[str, StrictStr]] = None
    response_body: Optional[Dict[str, Any]] = None
    response_headers: Optional[Dict[str, StrictStr]] = None
    searchable_tags: Optional[conlist(StrictStr)] = None
    status: Optional[StrictStr] = None
    updated_at: Optional[StrictStr] = None
    url: Optional[StrictStr] = None
    user_account_id: Optional[StrictStr] = None
    version: Optional[StrictStr] = None
    __properties = ["created_at", "id", "ip_address", "livemode", "loggable_id", "loggable_type", "method", "oauth_token_id", "query_string", "related", "request_body", "request_headers", "response_body", "response_headers", "searchable_tags", "status", "updated_at", "url", "user_account_id", "version"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LogsResponseData:
        """Create an instance of LogsResponseData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if loggable_id (nullable) is None
        # and __fields_set__ contains the field
        if self.loggable_id is None and "loggable_id" in self.__fields_set__:
            _dict['loggable_id'] = None

        # set to None if loggable_type (nullable) is None
        # and __fields_set__ contains the field
        if self.loggable_type is None and "loggable_type" in self.__fields_set__:
            _dict['loggable_type'] = None

        # set to None if oauth_token_id (nullable) is None
        # and __fields_set__ contains the field
        if self.oauth_token_id is None and "oauth_token_id" in self.__fields_set__:
            _dict['oauth_token_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LogsResponseData:
        """Create an instance of LogsResponseData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return LogsResponseData.parse_obj(obj)

        _obj = LogsResponseData.parse_obj({
            "created_at": obj.get("created_at"),
            "id": obj.get("id"),
            "ip_address": obj.get("ip_address"),
            "livemode": obj.get("livemode"),
            "loggable_id": obj.get("loggable_id"),
            "loggable_type": obj.get("loggable_type"),
            "method": obj.get("method"),
            "oauth_token_id": obj.get("oauth_token_id"),
            "query_string": obj.get("query_string"),
            "related": obj.get("related"),
            "request_body": obj.get("request_body"),
            "request_headers": obj.get("request_headers"),
            "response_body": obj.get("response_body"),
            "response_headers": obj.get("response_headers"),
            "searchable_tags": obj.get("searchable_tags"),
            "status": obj.get("status"),
            "updated_at": obj.get("updated_at"),
            "url": obj.get("url"),
            "user_account_id": obj.get("user_account_id"),
            "version": obj.get("version")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.transfers_api import TransfersApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestTransfersApi(unittest.TestCase):
    """TransfersApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.transfers_api.TransfersApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_get_transfer(self):
        """Test case for get_transfer

        Get Transfer  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_transfer('64462930651b2600017b6d43', accept_language)
        self.assertIsNotNone(response)

    def test_get_transfers(self):
        """Test case for get_transfers

        Get a list of transfers  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_transfers(accept_language, limit=5)
        self.assertIsNotNone(response)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class ApiKeyResponse(BaseModel):
    """
    api keys model
    """
    active: Optional[StrictBool] = Field(None, description="Indicates if the api key is active")
    created_at: Optional[StrictInt] = Field(None, description="Unix timestamp in seconds of when the api key was created")
    updated_at: Optional[StrictInt] = Field(None, description="Unix timestamp in seconds of when the api key was last updated")
    deactivated_at: Optional[StrictInt] = Field(None, description="Unix timestamp in seconds of when the api key was deleted")
    description: Optional[StrictStr] = Field(None, description="A name or brief explanation of what this api key is used for")
    id: Optional[StrictStr] = Field(None, description="Unique identifier of the api key")
    livemode: Optional[StrictBool] = Field(None, description="Indicates if the api key is in production")
    deleted: Optional[StrictBool] = Field(None, description="Indicates if the api key was deleted")
    object: Optional[StrictStr] = Field(None, description="Object name, value is 'api_key'")
    prefix: Optional[StrictStr] = Field(None, description="The first few characters of the authentication_token")
    role: Optional[StrictStr] = Field(None, description="Indicates if the api key is private or public")
    __properties = ["active", "created_at", "updated_at", "deactivated_at", "description", "id", "livemode", "deleted", "object", "prefix", "role"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiKeyResponse:
        """Create an instance of ApiKeyResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if deactivated_at (nullable) is None
        # and __fields_set__ contains the field
        if self.deactivated_at is None and "deactivated_at" in self.__fields_set__:
            _dict['deactivated_at'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiKeyResponse:
        """Create an instance of ApiKeyResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiKeyResponse.parse_obj(obj)

        _obj = ApiKeyResponse.parse_obj({
            "active": obj.get("active"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "deactivated_at": obj.get("deactivated_at"),
            "description": obj.get("description"),
            "id": obj.get("id"),
            "livemode": obj.get("livemode"),
            "deleted": obj.get("deleted"),
            "object": obj.get("object"),
            "prefix": obj.get("prefix"),
            "role": obj.get("role")
        })
        return _obj




# coding: utf-8

"""
    Conekta API

    Conekta sdk  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: engineering@conekta.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import conekta
from conekta import ApiClient
from conekta.api.charges_api import ChargesApi  # noqa: E501
from conekta.rest import ApiException
from test.test_utils import get_base_path


class TestChargesApi(unittest.TestCase):
    """ChargesApi unit test stubs"""

    def setUp(self):
        self.api = conekta.api.charges_api.ChargesApi(ApiClient(
            configuration=conekta.Configuration(host=get_base_path())
        ))  # noqa: E501

    def tearDown(self):
        pass

    def test_get_charges(self):
        """Test case for get_charges

        Get A List of Charges  # noqa: E501
        """
        accept_language = 'es'
        response = self.api.get_charges(accept_language, limit=20)
        self.assertIsNotNone(response)
        self.assertIsNotNone(response.data)
        self.assertIsNotNone(response.data[0].payment_method)
        self.assertIsInstance(response.data[0].payment_method.actual_instance, conekta.PaymentMethodCash)
        self.assertEqual('oxxo', response.data[0].payment_method.actual_instance.type)

    def test_orders_create_charge(self):
        """Test case for orders_create_charge

        Create charge  # noqa: E501
        """
        accept_language = 'es'
        charge_request = conekta.ChargeRequest(
            amount=1000,
            payment_method=conekta.ChargeRequestPaymentMethod(type='card')
        )
        response = self.api.orders_create_charge('ord_2tUigJ8DgBhbp6w5D', charge_request, accept_language)
        self.assertIsNotNone(response)
        self.assertIsNotNone(response.payment_method)
        self.assertIsInstance(response.payment_method.actual_instance, conekta.PaymentMethodCard)
        self.assertEqual('credit', response.payment_method.actual_instance.type)


if __name__ == '__main__':
    unittest.main()
